DSC plugin for Quantiphyse
==========================

This plugin provides modelling tools for DSC-MRI. 

Quantiphyse and quantiphyse-fabber must be installed. To
install the plugin from PyPi use:

    pip install quantiphyse-dsc

The plugin will then be available from within Quantiphyse

